@@ -35,8 +35,8 @@ public:
 
 	virtual void resolveConflict (const MergeTask & task, Key & conflictKey, MergeResult & result) override;
 };
-}
-}
-}
+} // namespace merging
+} // namespace tools
+} // namespace kdb
 
 #endif /* ONESIDEVALUESTRATEGY_HPP_ */
