@@ -18,6 +18,6 @@ int elektraBlockresolverGet (Plugin * handle, KeySet * ks, Key * parentKey);
 int elektraBlockresolverSet (Plugin * handle, KeySet * ks, Key * parentKey);
 int elektraBlockresolverError (Plugin * handle, KeySet * ks, Key * parentKey);
 
-Plugin * ELEKTRA_PLUGIN_EXPORT (blockresolver);
+Plugin * ELEKTRA_PLUGIN_EXPORT;
 
 #endif
