@@ -24,7 +24,7 @@ int elektraCppTemplateSet (Plugin * handle, KeySet * returned, Key * parentKey);
 int elektraCppTemplateError (Plugin * handle, KeySet * conf, Key * parentKey);
 int elektraCppTemplateCheckConfig (Key * errorKey, KeySet * conf);
 
-Plugin * ELEKTRA_PLUGIN_EXPORT (cpptemplate);
+Plugin * ELEKTRA_PLUGIN_EXPORT;
 } // end extern "C"
 
 #endif
