@@ -16,6 +16,6 @@
 int elektraCurlgetGet (Plugin * handle, KeySet * ks, Key * parentKey);
 int elektraCurlgetSet (Plugin * handle, KeySet * ks, Key * parentKey);
 int elektraCurlgetOpen (Plugin * handle, Key * errorKey);
-Plugin * ELEKTRA_PLUGIN_EXPORT (curlget);
+Plugin * ELEKTRA_PLUGIN_EXPORT;
 
 #endif
