@@ -18,6 +18,8 @@
 
 #include <errno.h>
 #include <stddef.h>
+// The definition `_WITH_GETLINE` is required for FreeBSD
+#define _WITH_GETLINE
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -143,7 +145,7 @@ int elektraLineSet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned, Key * par
 	return 1; /* success */
 }
 
-Plugin * ELEKTRA_PLUGIN_EXPORT (line)
+Plugin * ELEKTRA_PLUGIN_EXPORT
 {
 	// clang-format off
 	return elektraPluginExport("line",
