@@ -868,11 +868,11 @@ static void testDynArray (void)
 			      4405, 5021, 3416, 854,  4635, 9902, 5383, 7947, 5210, 8242, 1928, 3792, 7234, 759,  6571, 9514, 8451,
 			      918,  9958, 1577, 96,   8644, 6815, 5584, 8585, 1252, 808,  5695, 910,  4157, 701,  77 };
 
-	DynArray * dynArray = ELEKTRA_PLUGIN_FUNCTION (mmapstorage, dynArrayNew) ();
+	DynArray * dynArray = ELEKTRA_PLUGIN_FUNCTION (dynArrayNew) ();
 
 	for (size_t i = 0; i < 100; ++i)
 	{
-		ELEKTRA_PLUGIN_FUNCTION (mmapstorage, dynArrayFindOrInsert) ((Key *) testData[i], dynArray);
+		ELEKTRA_PLUGIN_FUNCTION (dynArrayFindOrInsert) ((Key *) testData[i], dynArray);
 	}
 
 	qsort (testData, 100, sizeof (size_t), cmpfunc);
@@ -888,7 +888,7 @@ static void testDynArray (void)
 
 	succeed_if (error == 0, "dynArray does not sort array properly");
 
-	ELEKTRA_PLUGIN_FUNCTION (mmapstorage, dynArrayDelete) (dynArray);
+	ELEKTRA_PLUGIN_FUNCTION (dynArrayDelete) (dynArray);
 }
 
 /* -- Main ------------------------------------------------------------------------------------------------------------------------------ */
