@@ -3,8 +3,6 @@
 #define PREFIX "user/examples/yamlcpp/"
 
 ksNew (10,
-       keyNew (PREFIX "bloc", KEY_END),
-       keyNew (PREFIX "bloc/party", KEY_END),
        keyNew (PREFIX "bloc/party/little", KEY_VALUE, "thoughts", KEY_END),
        keyNew (PREFIX "bloc/party/silent", KEY_VALUE, "alarm", KEY_END),
        KS_END)
