@@ -13,19 +13,18 @@ echo "Test specification get"
 ROOT_FILE=spec_tests.ecf
 ROOT_MOUNTPOINT=/test/script/spec
 
-if is_plugin_available dump && is_plugin_available list && is_plugin_available sync
-then
-	"$KDB" mount $ROOT_FILE $ROOT_MOUNTPOINT dump 1>/dev/null
+if is_plugin_available dump && is_plugin_available list && is_plugin_available sync; then
+	"$KDB" mount $ROOT_FILE $ROOT_MOUNTPOINT dump 1> /dev/null
 	succeed_if "could not mount root: $ROOT_FILE at $ROOT_MOUNTPOINT"
 
-	SYSTEM_FILE="`"$KDB" file -n system$ROOT_MOUNTPOINT`"
+	SYSTEM_FILE="$("$KDB" file -n system$ROOT_MOUNTPOINT)"
 	[ ! -f $SYSTEM_FILE ]
 	exit_if_fail "System File $SYSTEM_FILE already exists"
 
-	"$KDB" mount $ROOT_FILE spec$ROOT_MOUNTPOINT dump 1>/dev/null
+	"$KDB" mount $ROOT_FILE spec$ROOT_MOUNTPOINT dump 1> /dev/null
 	succeed_if "could not mount spec root: $ROOT_FILE at spec$ROOT_MOUNTPOINT"
 
-	SPEC_FILE="`"$KDB" file -n spec$ROOT_MOUNTPOINT`"
+	SPEC_FILE="$("$KDB" file -n spec$ROOT_MOUNTPOINT)"
 	[ ! -f $SPEC_FILE ]
 	exit_if_fail "Spec File $SPEC_FILE already exists"
 
@@ -43,7 +42,7 @@ then
 	"$KDB" setmeta spec$ROOT_MOUNTPOINT/first default 20
 	succeed_if "could not set meta"
 
-	[ "x`"$KDB" get $ROOT_MOUNTPOINT/first`" = "x20" ]
+	[ "x$("$KDB" get $ROOT_MOUNTPOINT/first)" = "x20" ]
 	succeed_if "could not get default value"
 
 	"$KDB" umount $ROOT_MOUNTPOINT
